@@ -2,7 +2,7 @@
 
 # This test can only run if netcat is present
 #
-if ! type nc >/dev/null; then exit; fi
+if ! type nc >/dev/null; then exit 77; fi
 
 PORT=54325			# Some port that is unlikely to be in use
 
@@ -18,7 +18,7 @@ while [ $(( ( i += 1 ) <= 10 )) -ne 0 ]; do
   p=$(($PORT + $i))
   q=$(($p + 1))
   printf "HTTP/1.1 302\r\nLocation: http://127.0.0.1:$q/\r\n\r" |\
-    (nc -l -n -p $p || nc -l -n $p) >/dev/null 2>&1 &
+    (nc -N -l -n -p $p || nc -l -n $p) >/dev/null 2>&1 &
 done
 
 sleep 1				# Give the servers time to start
